@@ -1,7 +1,9 @@
-from peek_core_search._private.client.controller.FastKeywordController import \
-    FastKeywordController
-from peek_core_search._private.tuples.KeywordAutoCompleteTupleAction import \
-    KeywordAutoCompleteTupleAction
+from peek_core_search._private.client.controller.FastKeywordController import (
+    FastKeywordController,
+)
+from peek_core_search._private.tuples.KeywordAutoCompleteTupleAction import (
+    KeywordAutoCompleteTupleAction,
+)
 from peek_plugin_base.PeekVortexUtil import peekServerName
 from peek_core_search._private.PluginNames import searchFilt
 from peek_core_search._private.PluginNames import searchActionProcessorName
@@ -12,9 +14,9 @@ def makeTupleActionProcessorProxy(fastKeywordController: FastKeywordController):
     proxy = TupleActionProcessorProxy(
         tupleActionProcessorName=searchActionProcessorName,
         proxyToVortexName=peekServerName,
-        additionalFilt=searchFilt)
+        additionalFilt=searchFilt,
+    )
 
-    proxy.setDelegate(KeywordAutoCompleteTupleAction.tupleType(),
-                      fastKeywordController)
+    proxy.setDelegate(KeywordAutoCompleteTupleAction.tupleType(), fastKeywordController)
 
     return proxy
